summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoGenStyles.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoGenStyles.h')
-rw-r--r--lib/kofficecore/KoGenStyles.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kofficecore/KoGenStyles.h b/lib/kofficecore/KoGenStyles.h
index 17771c69..ad25609e 100644
--- a/lib/kofficecore/KoGenStyles.h
+++ b/lib/kofficecore/KoGenStyles.h
@@ -216,10 +216,10 @@ public:
* @param familyName The value for style:family, e.g. text, paragraph, graphic etc.
* The family is for style:style elements only; number styles and list styles don't have one.
*
* @param tqparentName If set, name of the tqparent style from which this one inherits.
*/
explicit KoGenStyle( int type = 0, const char* familyName = 0,
- const TQString& tqparentName = TQString() );
+ const TQString& parentName = TQString() );
~KoGenStyle();
/*
@@ -250,7 +250,7 @@ public:
const char* familyName() const { return m_familyName.data(); }
/// Return the name of style's tqparent, if set
- TQString tqparentName() const { return m_parentName; }
+ TQString parentName() const { return m_parentName; }
/**
* @brief The types of properties
@@ -434,7 +434,7 @@ private:
}
void writeStyleProperties( KoXmlWriter* writer, PropertyType i,
- const char* elementName, const KoGenStyle* tqparentStyle ) const;
+ const char* elementName, const KoGenStyle* parentStyle ) const;
#ifndef NDEBUG
void printDebug() const;
@@ -216,10 +216,10 @@ public:
* The family is for style:style elements only; number styles and list styles don't have one.
*
- * @param tqparentName If set, name of the tqparent style from which this one inherits.
+ * @param parentName If set, name of the tqparent style from which this one inherits.
*/
explicit KoGenStyle( int type = 0, const char* familyName = 0,